HighChartsYAxis class

Constructors

HighChartsYAxis({HighChartsAxisTitle? title, HighChartsAxisLabels? labels, double? min, double? max, double? gridLineWidth})

Properties

gridLineWidth → double?
final
hashCode → int
The hash code for this object.
no setterinherited
labels → HighChartsAxisLabels?
final
max → double?
final
min → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → HighChartsAxisTitle?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited